#!/usr/bin/env python

import os

from pipenv.project import Project
from pipenv.utils import convert_deps_to_pip

"""
This is a generation file that uses pipenv to regenerate the requirements file.
This tool allows for development only requirements that each developer can use separate of the
production tool set.

http://docs.pipenv.org/en/latest/
"""


def rebuild():
    os.system('pipenv lock')
    packages = Project().parsed_pipfile.get('packages', {})
    deps = convert_deps_to_pip(packages, r=False)

    with open('requirements.txt', 'w') as f:
        print(deps)
        f.write('\n'.join(sorted(deps)))


def install():
    os.system('pipenv install $(< requirements.txt)')
    print('Yeppers')



from setuptools import setup

setup(name='pipenv-package-requirements',
      version='0.1',
      description='Pipenv tools for requirements.txt',
      url='https://github.com/Blue-Dog-Archolite/pipenv-package-requirements',
      author='Robert R. Meyer',
      author_email='Blue.Dog.Archolite@gmail.com',
      license='GNU',
      packages=['pipenv_tools'],
      zip_safe=True,
      console_scripts=[
          'rebuild_requirements=pipenv_tools.command_line:rebuild',
          'install_requirements=pipenv_tools.command_line:install',
      ],
      keywords='pipenv virtualenv',
      install_requires=[
          'pipenv',
      ],
      )
